@@ -280,13 +280,15 @@ struct _WnckWindowClass
   /* Changed role */
   void (* role_changed)      (WnckWindow       *window);
 
+  void (* type_changed)      (WnckWindow       *window);
+
   /* Padding for future expansion */
   void (* pad1) (void);
-  void (* pad2) (void);
 };
 
 GType wnck_window_get_type (void) G_GNUC_CONST;
 
+G_DEPRECATED_FOR(wnck_handle_get_window)
 WnckWindow* wnck_window_get (gulong xwindow);
 
 WnckScreen* wnck_window_get_screen    (WnckWindow *window);
